#    This file is part of MDANSE.
#
#    MDANSE is free software: you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation, either version 3 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program.  If not, see <https://www.gnu.org/licenses/>.
#

import os

from MDANSE import PLATFORM
from MDANSE.Framework.Configurators.IConfigurator import IConfigurator


class InputDirectoryConfigurator(IConfigurator):
    """
    This Configurator allows to set an input directory.

    :attention: The directory will be created at configuration time if it does not exist.
    """

    _default = os.getcwd()

    def configure(self, value):
        """
        Configure an input directory.

        :param configuration: the current configuration.
        :type configuration: a MDANSE.Framework.Configurable.Configurable object
        :param value: the input directory.
        :type value: str
        """
        self._original_input = value

        value = PLATFORM.get_path(value)

        PLATFORM.create_directory(value)

        self["value"] = value

    def get_information(self):
        """
        Returns some informations about this configurator.

        :return: the information about this configurator
        :rtype: str
        """
        if "value" not in self:
            return "Not configured yet\n"

        return "Input directory: %r\n" % self["value"]
